@@ -24,6 +24,7 @@ from typing import Optional
 import click
 import toml
 
+from streamlit import util
 from streamlit import env_util
 from streamlit import file_util
 from streamlit import config
@@ -116,6 +117,9 @@ class Credentials(object):
 
         Credentials._singleton = self
 
+    def __repr__(self) -> str:
+        return util.repr_(self)
+
     def load(self, auto_resolve=False) -> None:
         """Load from toml file."""
         if self.activation is not None:
