@@ -16,7 +16,8 @@ from typing import cast
 
 import streamlit
 from streamlit.proto.Checkbox_pb2 import Checkbox as CheckboxProto
-from .utils import register_widget
+from streamlit.widgets import register_widget
+from .form import current_form_id
 
 
 class CheckboxMixin:
@@ -54,6 +55,7 @@ class CheckboxMixin:
         checkbox_proto = CheckboxProto()
         checkbox_proto.label = label
         checkbox_proto.default = bool(value)
+        checkbox_proto.form_id = current_form_id(self.dg)
         if help is not None:
             checkbox_proto.help = help
 
