@@ -107,15 +107,15 @@ class LayoutsMixin:
         >>>
         >>> with col1:
         ...    st.header("A cat")
-        ...    st.image("https://static.streamlit.io/examples/cat.jpg", use_column_width=True)
+        ...    st.image("https://static.streamlit.io/examples/cat.jpg")
         ...
         >>> with col2:
         ...    st.header("A dog")
-        ...    st.image("https://static.streamlit.io/examples/dog.jpg", use_column_width=True)
+        ...    st.image("https://static.streamlit.io/examples/dog.jpg")
         ...
         >>> with col3:
         ...    st.header("An owl")
-        ...    st.image("https://static.streamlit.io/examples/owl.jpg", use_column_width=True)
+        ...    st.image("https://static.streamlit.io/examples/owl.jpg")
 
         .. output ::
             https://static.streamlit.io/0.66.0-Wnid/index.html?id=VW45Va5XmSKed2ayzf7vYa
