@@ -18,7 +18,8 @@ import streamlit
 from streamlit.errors import StreamlitAPIException
 from streamlit.proto.Slider_pb2 import Slider as SliderProto
 from streamlit.type_util import ensure_iterable
-from .utils import register_widget
+from streamlit.widgets import register_widget
+from .form import current_form_id
 
 
 class SelectSliderMixin:
@@ -123,6 +124,7 @@ class SelectSliderMixin:
         slider_proto.step = 1  # default for index changes
         slider_proto.data_type = SliderProto.INT
         slider_proto.options[:] = [str(format_func(option)) for option in options]
+        slider_proto.form_id = current_form_id(self.dg)
         if help is not None:
             slider_proto.help = help
 
