@@ -20,7 +20,8 @@ from streamlit.errors import StreamlitAPIException
 from streamlit.js_number import JSNumber
 from streamlit.js_number import JSNumberBoundsException
 from streamlit.proto.Slider_pb2 import Slider as SliderProto
-from .utils import register_widget
+from streamlit.widgets import register_widget
+from .form import current_form_id
 
 
 class SliderMixin:
@@ -375,6 +376,7 @@ class SliderMixin:
         slider_proto.step = step
         slider_proto.data_type = data_type
         slider_proto.options[:] = []
+        slider_proto.form_id = current_form_id(self.dg)
         if help is not None:
             slider_proto.help = help
 
