@@ -12,6 +12,8 @@
 # See the License for the specific language governing permissions and
 # limitations under the License.
 
+from streamlit import util
+
 
 class Error(Exception):
     pass
@@ -59,6 +61,9 @@ class StreamlitAPIException(MarkdownFormattedException):
 
     pass
 
+    def __repr__(self) -> str:
+        return util.repr_(self)
+
 
 class DuplicateWidgetID(StreamlitAPIException):
     pass
@@ -79,6 +84,9 @@ class StreamlitAPIWarning(StreamlitAPIException, Warning):
         f = inspect.currentframe()
         self.tacked_on_stack = traceback.extract_stack(f)
 
+    def __repr__(self) -> str:
+        return util.repr_(self)
+
 
 class StreamlitDeprecationWarning(StreamlitAPIWarning):
     """Used to display a warning.
@@ -109,3 +117,6 @@ or in your `.streamlit/config.toml`
         # For more details, please see: https://docs.streamlit.io/path/to/deprecation/docs.html
 
         super(StreamlitAPIWarning, self).__init__(message, *args)
+
+    def __repr__(self) -> str:
+        return util.repr_(self)
