@@ -23,7 +23,6 @@ import streamlit.elements.exception as exception
 from streamlit import __version__
 from streamlit import caching
 from streamlit import config
-from streamlit import theme
 from streamlit import url_util
 from streamlit import util
 from streamlit.case_converters import to_snake_case
@@ -33,6 +32,7 @@ from streamlit.media_file_manager import media_file_manager
 from streamlit.metrics_util import Installation
 from streamlit.proto.ClientState_pb2 import ClientState
 from streamlit.proto.ForwardMsg_pb2 import ForwardMsg
+from streamlit.proto.GitInfo_pb2 import GitInfo
 from streamlit.proto.NewReport_pb2 import Config, CustomThemeConfig, UserInfo
 from streamlit.report import Report
 from streamlit.script_request_queue import RerunData
@@ -63,6 +63,7 @@ class ReportSession(object):
     and widget state.
 
     A ReportSession is attached to each thread involved in running its Report.
+
     """
 
     def __init__(self, ioloop, script_path, command_line, uploaded_file_manager):
@@ -353,21 +354,9 @@ class ReportSession(object):
         msg.session_event.report_changed_on_disk = True
         self.enqueue(msg)
 
-    def get_deploy_params(self):
-        try:
-            from streamlit.git_util import GitRepo
-
-            self._repo = GitRepo(self._report.script_path)
-            return self._repo.get_repo_info()
-        except:
-            # Issues can arise based on the git structure
-            # (e.g. if branch is in DETACHED HEAD state,
-            # git is not installed, etc)
-            # In this case, catch any errors
-            return None
-
     def _enqueue_new_report_message(self):
         self._report.generate_new_id()
+
         msg = ForwardMsg()
 
         msg.new_report.report_id = self._report.report_id
@@ -377,14 +366,6 @@ class ReportSession(object):
         _populate_config_msg(msg.new_report.config)
         _populate_theme_msg(msg.new_report.custom_theme)
 
-        # git deploy params
-        deploy_params = self.get_deploy_params()
-        if deploy_params is not None:
-            repo, branch, module = deploy_params
-            msg.new_report.deploy_params.repository = repo
-            msg.new_report.deploy_params.branch = branch
-            msg.new_report.deploy_params.module = module
-
         # Immutable session data. We send this every time a new report is
         # started, to avoid having to track whether the client has already
         # received it. It does not change from run to run; it's up to the
@@ -418,6 +399,40 @@ class ReportSession(object):
         msg.report_finished = status
         self.enqueue(msg)
 
+    def handle_git_information_request(self):
+        msg = ForwardMsg()
+
+        try:
+            from streamlit.git_util import GitRepo
+
+            repo = GitRepo(self._report.script_path)
+
+            repo_info = repo.get_repo_info()
+            if repo_info is None:
+                return
+
+            repository_name, branch, module = repo_info
+
+            msg.git_info_changed.repository = repository_name
+            msg.git_info_changed.branch = branch
+            msg.git_info_changed.module = module
+
+            msg.git_info_changed.untracked_files[:] = repo.untracked_files
+            msg.git_info_changed.uncommitted_files[:] = repo.uncommitted_files
+
+            if repo.is_head_detached:
+                msg.git_info_changed.state = GitInfo.GitStates.HEAD_DETACHED
+            elif len(repo.ahead_commits) > 0:
+                msg.git_info_changed.state = GitInfo.GitStates.AHEAD_OF_REMOTE
+            else:
+                msg.git_info_changed.state = GitInfo.GitStates.DEFAULT
+
+            self.enqueue(msg)
+        except Exception as e:
+            # Users may never even install Git in the first place, so this
+            # error requires no action. It can be useful for debugging.
+            LOGGER.debug("Obtaining Git information produced an error", exc_info=e)
+
     def handle_rerun_script_request(self, client_state=None, is_preheat=False):
         """Tell the ScriptRunner to re-run its report.
 
@@ -426,6 +441,7 @@ class ReportSession(object):
         client_state : streamlit.proto.ClientState_pb2.ClientState | None
             The ClientState protobuf to run the script with, or None
             to use previous client state.
+
         is_preheat: boolean
             True if this ReportSession should run the script immediately, and
             then ignore the next rerun request if it matches the already-ran
@@ -629,29 +645,50 @@ def _populate_config_msg(msg: Config) -> None:
 
 
 def _populate_theme_msg(msg: CustomThemeConfig) -> None:
+    enum_encoded_options = {"base", "font"}
     theme_opts = config.get_options_for_section("theme")
 
-    if (
-        theme.check_theme_completeness(theme_opts)
-        != theme.ThemeCompleteness.FULLY_DEFINED
-    ):
+    if not any(theme_opts.values()):
         return
 
     for option_name, option_val in theme_opts.items():
-        # We don't set the "font" option here as it needs to be converted
-        # from string -> enum.
-        if option_name != "font" and option_val is not None:
+        if option_name not in enum_encoded_options and option_val is not None:
             setattr(msg, to_snake_case(option_name), option_val)
 
+    # NOTE: If unset, base and font will default to the protobuf enum zero
+    # values, which are BaseTheme.LIGHT and FontFamily.SANS_SERIF,
+    # respectively. This is why we both don't handle the cases explicitly and
+    # also only log a warning when receiving invalid base/font options.
+    base_map = {
+        "light": msg.BaseTheme.LIGHT,
+        "dark": msg.BaseTheme.DARK,
+    }
+    base = theme_opts["base"]
+    if base is not None:
+        if base not in base_map:
+            LOGGER.warning(
+                f'"{base}" is an invalid value for theme.base.'
+                f" Allowed values include {list(base_map.keys())}."
+                ' Setting theme.base to "light".'
+            )
+        else:
+            msg.base = base_map[base]
+
     font_map = {
         "sans serif": msg.FontFamily.SANS_SERIF,
         "serif": msg.FontFamily.SERIF,
         "monospace": msg.FontFamily.MONOSPACE,
     }
-    msg.font = font_map.get(
-        config.get_option("theme.font"),
-        msg.FontFamily.SANS_SERIF,
-    )
+    font = theme_opts["font"]
+    if font is not None:
+        if font not in font_map:
+            LOGGER.warning(
+                f'"{font}" is an invalid value for theme.font.'
+                f" Allowed values include {list(font_map.keys())}."
+                ' Setting theme.font to "sans serif".'
+            )
+        else:
+            msg.font = font_map[font]
 
 
 def _populate_user_info_msg(msg: UserInfo) -> None:
